*******************************************************************************
*
* Function..: file_def
* Purpose...: Search a file and stuff a value in a variable.
* Parameters:
*   Name	Type	Description.
* --------------------------------------------------------------------------
*   pfile	Char  	File to use.
*   pkey	?   	Key to search for.
*			The type is the type of expression in the index
*			you are searching.  For example, to search for
*			mcust_no (type N) where the index is made of
*			STR(CUST_NO), pkey should be str(mcust_no, ?).
*   pfield	Char    The field from "pfile" to get value.
*   pvar	Char    The memory variable to put "pfield" into (defaults
*                       to the 'm'+pfield if not sent.
* --------------------------------------------------------------------------
*
* Returns...: .t. for valid function.
* Notes.....: Created for use in defaulting a value in an entry screen.
*
*	      file_def("CSMA", str(mcust_no, 10), "NAME") would search the
*	      Customer Reference file "CSMA" for the string of mcust_no.
*             It will put the field "NAME" from the found record into the
*   	      memory variable "mname" for automatic default.
* 	      ONLY works in <add> mode.
*
*******************************************************************************

function file_def
parameters pfile, pkey, pfield, pmvar

if (mq_mode != "<add>")			&& Function only works in Add Mode.
   return (.t.)				&& Ignore call and continue.
endif

if (type("PMVAR") = 'U')		&& Not sent, default.
   pmvar = 'm'+pfield
endif

private inuse, ;			&& Is file already open?
	curscr, ;			&& Current screen.
	oldarea, ;			&& Current work area.
	result, ;			&& Result of "seek".
	trec				&& Current record no if inuse.

inuse = .f.				&& Defa is no.

if (empty(pkey))			&& No value sent, error.
   return (.f.)
endif

oldarea = select()			&& Get current work area.
trec = recno()				&& Save for later.

if (select(pfile) > 0)			&& Already in use.
   select &pfile.
   inuse = .t.
else
   select 0
   use (pfile) index (pfile)
endif

seek pkey				&& Look for the value.
result = found()			&& Was it found?

if (result)				&& Only default if found.
   &pmvar. = &pfield.			&& Put contents of field in variable.
   n_reget()				&& Re-display if on screen.
endif

if (!inuse)
   use					&& Close File.
endif

select(oldarea)				&& Back to original work area.
*go trec					&& Back to current record.

return (.t.)

